# Generated by Django 4.2.6 on 2023-10-07 09:55

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("cjkcms", "0015_eventcalendar"),
    ]

    operations = [
        migrations.AddField(
            model_name="layoutsettings",
            name="breadcrumb_icon",
            field=models.CharField(
                blank=True,
                default="slash",
                help_text="Bootstrap icon name. See docs for built-in options.",
                max_length=32,
                verbose_name="Breadcrumb icon",
            ),
        ),
        migrations.AddField(
            model_name="layoutsettings",
            name="breadcrumbs",
            field=models.BooleanField(
                default=False,
                help_text="Show breadcrumbs in page header",
                verbose_name="Breadcrumbs",
            ),
        ),
    ]



import os
import shutil
import sys
import unittest
from unittest import mock
from io import StringIO

from cjkcms.bin.cjkcms import main as cms_main
from cjkcms.bin.cjkcms import CreateProject


class TestCjkcmsStart(unittest.TestCase):
    CURR_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
    TEST_DIR = os.path.join(CURR_DIR, "testproject-unittest")

    def setup(self):
        # Clean/create directory to start into
        if os.path.exists(self.TEST_DIR):
            shutil.rmtree(self.TEST_DIR)
        os.mkdir(self.TEST_DIR)

    def cleanup(self):
        # Cleanup
        if os.path.exists(self.TEST_DIR):
            shutil.rmtree(self.TEST_DIR)

    def test_help(self):
        # Set args
        sys.argv = ["cjkcms", "help"]

        # Create a StringIO object to capture the console output
        out = StringIO()
        with mock.patch.object(sys, "stdout", new=out):
            # Run
            cms_main()
        self.assertIn("start", out.getvalue())
        self.assertIn(CreateProject.help, out.getvalue())

    def test_help_start(self):
        # Set args
        sys.argv = ["cjkcms", "help", "start"]

        out = StringIO()
        with mock.patch.object(sys, "stdout", new=out):
            # Run
            cms_main()
        self.assertIn("name", out.getvalue())
        self.assertIn("[directory]", out.getvalue())

    def test_default(self):
        self.setup()
        # Set args
        sys.argv = ["cjkcms", "start", "myproject", self.TEST_DIR]
        # prevent output
        out = StringIO()
        with mock.patch.object(sys, "stdout", new=out):
            # Run
            cms_main()
        # Assert files exist
        self.assertTrue(os.path.exists(os.path.join(self.TEST_DIR, "README.md")))
        self.cleanup()

    def test_allopts(self):
        self.setup()
        # Set args
        sys.argv = [
            "cjkcms",
            "start",
            "myproject",
            self.TEST_DIR,
            "--template",
            "basic",
            "--sitename",
            "CjkCorp, Inc.",
            "--domain",
            "example.com",
        ]
        # prevent output
        out = StringIO()
        with mock.patch.object(sys, "stdout", new=out):
            # Run
            cms_main()
        # Assert files exist
        self.assertTrue(os.path.exists(os.path.join(self.TEST_DIR, "README.md")))
        self.cleanup()

    def test_domain_www(self):
        self.setup()
        # Set args
        sys.argv = [
            "cjkcms",
            "start",
            "superproject",
            self.TEST_DIR,
            "--domain",
            "www.superproject.com",
        ]
        # prevent output
        out = StringIO()
        with mock.patch.object(sys, "stdout", new=out):
            # Run
            cms_main()

        # Assert files exist
        self.assertTrue(os.path.exists(os.path.join(self.TEST_DIR, "README.md")))
        self.cleanup()

    def test_template_sass(self):
        self.setup()
        # Set args
        sys.argv = [
            "cjkcms",
            "start",
            "webpack_project",
            self.TEST_DIR,
            "--template",
            "webpack",
        ]
        # prevent output
        out = StringIO()
        with mock.patch.object(sys, "stdout", new=out):
            # Run
            cms_main()

        # Assert files exist
        self.assertTrue(os.path.exists(os.path.join(self.TEST_DIR, "README.md")))
        self.cleanup()



from typing import Optional, Dict
from wagtail.admin.rich_text.converters.html_to_contentstate import (
    BlockElementHandler,
    InlineStyleElementHandler,
)
from wagtail.admin.rich_text.editors.draftail.features import (
    InlineStyleFeature,
    BlockFeature,
)
from wagtail.rich_text import LinkHandler
from django.utils.html import escape


def create_control_dict(
    type_: str,
    description: str,
    label: Optional[str] = None,
    icon: Optional[str] = None,
    editor_style: Optional[str] = None,
) -> Dict[str, str]:
    """
    Helper function to create a control dictionary.
    """
    control = {"type": type_, "description": description}
    if label:
        control["label"] = label
    elif icon:
        control["icon"] = icon
    else:
        control["label"] = description
    if editor_style:
        control["style"] = editor_style
    return control


def register_inline_styling(
    features,
    feature_name: str,
    description: str,
    type_: str,
    tag: str = "span",
    format: Optional[str] = None,
    editor_style: Optional[str] = None,
    label: Optional[str] = None,
    icon: Optional[str] = None,
):
    """
    Registers an inline style feature in the Wagtail editor.
    """
    control = create_control_dict(type_, description, label, icon, editor_style)

    style_map = f"{tag} {format}" if format else {"element": tag}
    markup_map = f"{tag}[{format}]" if format else tag

    features.register_editor_plugin(
        "draftail", feature_name, InlineStyleFeature(control)
    )
    db_conversion = {
        "from_database_format": {markup_map: InlineStyleElementHandler(type_)},
        "to_database_format": {"style_map": {type_: style_map}},
    }
    features.register_converter_rule("contentstate", feature_name, db_conversion)


def register_block_feature(
    features,
    feature_name: str,
    description: str,
    type_: str,
    css_class: str,
    element: str = "div",
    label: Optional[str] = None,
    icon: Optional[str] = None,
    editor_style: Optional[str] = None,
):
    """
    Registers a block feature in the Wagtail editor.
    """
    control = create_control_dict(type_, description, label, icon, editor_style)
    control["element"] = element

    features.register_editor_plugin("draftail", feature_name, BlockFeature(control))
    features.register_converter_rule(
        "contentstate",
        feature_name,
        {
            "from_database_format": {
                f"{element}[class={css_class}]": BlockElementHandler(type_)
            },
            "to_database_format": {
                "block_map": {
                    type_: {"element": element, "props": {"class": css_class}}
                }
            },
        },
    )


class NewWindowExternalLinkHandler(LinkHandler):
    """
    A link handler for opening external links in a new window.
    """

    identifier = "external"

    @classmethod
    def expand_db_attributes(cls, attrs: Dict[str, str]) -> str:
        href = attrs["href"]
        if href.endswith("?_blank"):
            href = href[:-7]
            return (
                f'<a href="{escape(href)}" target="_blank" rel="noopener noreferrer">'
            )
        return f'<a href="{escape(href)}">'



# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = "{{ secret_key }}"

# Add your site's domain name(s) here. Disabled by default on localhost.
# ALLOWED_HOSTS = ["{{ domain }}"]

# Default email address used to send messages from the website.
DEFAULT_FROM_EMAIL = "{{ sitename }} <info@{{ domain_nowww }}>"

# A list of people who get error notifications.
ADMINS = [
    ("Administrator", "admin@{{ domain_nowww }}"),
]

# A list in the same format as ADMINS that specifies who should get broken link
# (404) notifications when BrokenLinkEmailsMiddleware is enabled.
MANAGERS = ADMINS

# Email address used to send error messages to ADMINS.
SERVER_EMAIL = DEFAULT_FROM_EMAIL
